@@ -25,6 +25,13 @@
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
+/**
+ * SECTION:goc-rectangle
+ * @short_description: Rectangle.
+ *
+ * #GocPolygon implements rectangle drawing in the canvas.
+**/
+
 enum {
 	RECT_PROP_0,
 	RECT_PROP_X,
@@ -178,7 +185,9 @@ goc_rectangle_init_style (G_GNUC_UNUSED GocStyledItem *item, GOStyle *style)
 	if (style->fill.auto_type)
 		style->fill.type  = GO_STYLE_FILL_PATTERN;
 	if (style->fill.auto_fore)
-		go_pattern_set_solid (&style->fill.pattern, GO_COLOR_WHITE);
+		style->fill.pattern.fore = GO_COLOR_BLACK;
+	if (style->fill.auto_back)
+		style->fill.pattern.back = GO_COLOR_WHITE;
 }
 
 static void
@@ -192,7 +201,7 @@ goc_rectangle_class_init (GocItemClass *item_klass)
 	g_object_class_install_property (obj_klass, RECT_PROP_X,
 		g_param_spec_double ("x",
 			_("x"),
-			_("The rectangle left position"),
+			_("The rectangle left position (or right position in RTL mode)"),
 			-G_MAXDOUBLE, G_MAXDOUBLE, 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (obj_klass, RECT_PROP_Y,
