@@ -25,6 +25,13 @@
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
+/**
+ * SECTION:goc-text
+ * @short_description: Text.
+ *
+ * #GocText implements rich text drawing in the canvas.
+**/
+
 enum {
 	TEXT_PROP_0,
 	TEXT_PROP_X,
@@ -354,6 +361,7 @@ goc_text_draw (GocItem const *item, cairo_t *cr)
 		cairo_clip (cr);
 	}
 	pango_cairo_show_layout (cr, pl);
+	cairo_new_path (cr);
 	cairo_restore (cr);
 	g_object_unref (pl);
 }
